#
# spec file for package perl-HTML-Parser
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with opt

Name:           perl-HTML-Parser
Version:        3.71
Release:        6.13
%define cpan_name HTML-Parser
Summary:        HTML parser class
License:        GPL-1.0+ or Artistic-1.0
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/HTML-Parser/
Source:         http://www.cpan.org/modules/by-module/HTML/HTML-Parser-%{version}.tar.gz
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{perl_requires}
%if %{with opt}
BuildRequires:  perl(HTTP::Headers)
BuildRequires:  perl(Test::Pod) >= 1.00
%endif
BuildRequires:  perl(HTML::Tagset) >= 3
BuildRequires:  perl(Test::More)
BuildRequires:  perl(XSLoader)
#
Requires:       perl(HTML::Tagset) >= 3
Requires:       perl(XSLoader)
%if 0%{?suse_version} > 1010
Suggests:       perl(HTTP::Headers)
%endif

%description
Objects of the HTML::Parser class will recognize markup and separate it
from plain text (alias data content) in HTML documents. As different
kinds of markup and text are recognized, the corresponding event handlers
are invoked.

HTML::Parser is not a generic SGML parser. We have tried to make it able to
deal with the HTML that is actually "out there", and it normally parses as
closely as possible to the way the popular web browsers do it instead of
strictly following one of the many HTML specifications from W3C. Where
there is disagreement, there is often an option that you can enable to
get the official behaviour.

The document to be parsed may be supplied in arbitrary chunks. This makes
on-the-fly parsing as documents are received from the network possible.

If event driven parsing does not feel right for your application, you might
want to use HTML::PullParser. This is an HTML::Parser subclass that allows
a more conventional program structure.

%prep
%setup -q -n %{cpan_name}-%{version}
# rpmlint: spurious-executable-perm
find ./eg -type f -exec chmod 0644 {} \;
chmod 0644 mkpfunc mkhctype

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%clean
rm -rf %{buildroot}

%files -f %{name}.files
%defattr(-,root,root,-)
%doc Changes mkhctype mkpfunc README TODO eg

%changelog
* Tue Oct 15 2013 nine@detonation.org
- update to 3.71
    Transform ':' in headers to '-' [RT#80524]
    Fix for cross-compiling with Buildroot
    Comment typo fix
    Fix Issue #3 / RT #84144: HTML::Entities::decode_entities() needs
    to call SV_CHECK_THINKFIRST() before checking READONLY flag
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Mon Oct 17 2011 vcizek@suse.com
- update to 3.69
    Documentation fix; encode_utf8 mixup [RT#71151]
    Make it clearer that there are 2 (actually 3) options for handing "UTF-8 garbage"
    Github is the official repo
    Can't be bothered to try to fix the failures that occur on perl-5.6
    fix to TokeParser to correctly handle option configuration
    Aesthetic change: remove extra ;
    Trim surrounding whitespace from extracted URLs.
  _______________________________________________________________________________
* Thu Aug 25 2011 chris@computersalat.de
- fix build for RHEL, CentOS
  * Unknown tag: Suggests:
* Fri Feb 11 2011 vcizek@novell.com
- changed Recommends: perl(HTTP:Headers) to Suggests
  (bnc#570870)
* Thu Feb 10 2011 chris@computersalat.de
- remove Author
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Sep  6 2010 chris@computersalat.de
- recreated by cpanspec 1.78
- fix deps
  o Recommends HTTP::Headers not HTML::Headers
* Thu Sep  2 2010 pascal.bleser@opensuse.org
- replaced auto-generated spec file
- update to 3.68:
  * declare the encoding of the POD to be utf8
* Fri Aug 20 2010 chris@computersalat.de
- recreated by cpanspec 1.78
  o fix deps
- added bcond_with opt
* Wed Aug 18 2010 dmueller@suse.de
- update to 3.67:
  * bleadperl 2154eca7 breaks HTML::Parser 3.66
* Mon Jul 12 2010 dmueller@suse.de
- update to 3.66:
  * Fix entity decoding in utf8_mode for the title header
* Wed Apr  7 2010 chris@computersalat.de
- update to 3.65
  * Eliminate buggy entities_decode_old
  * Fixed endianness typo [RT#50811]
  * Documentation fixes.
* Wed Jan 13 2010 anicka@suse.cz
- update to 3.64
  * Convert files to UTF-8
  * Don't allow decode_entities() to generate illegal Unicode chars
  * Copyright 2009
  * Remove rendundant (repeated) test
  * Make parse_file() method use 3-arg open [RT#49434]
  * Take more care to prepare the char range for encode_entities [RT#50170]
  * decode_entities confused by trailing incomplete entity
  * HTTP::Header doc typo fix.
  * Do not bother tracking style or script, they're ignored.
  * Bring HTML 5 head elements up to date with WD-html5-20090423.
  * Improve HeadParser performance.
  * Doc patch: Make it clearer what the return value from ->parse is
- remove last patch (fixed in upstream)
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Thu Oct 29 2009 anicka@suse.cz
- fixed CVE-2009-3627 (bnc#550076)
* Thu Aug 27 2009 coolo@novell.com
- remove strange obsoletes
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Sun Jun 28 2009 chris@computersalat.de
- update to 3.61
  * Test that triggers the crash that Chip fixed
  * Complete documented list of literal tags
  * Avoid crash (referenced pend_text instead of skipped_text)
  * Reference HTML::LinkExttor [RT#43164]
- added perl-macros
  o autogen filelist with perl_gen_filelist
- spec mods
  o fixed deps
- fixed rpmlint warnings
  o spurious-executable-perm in doc
* Fri Feb 27 2009 anicka@suse.cz
- update to 3.60
  * Spelling fixes.
  * Test multi-value headers.
  * Documentation improvements.
  * Do not terminate head parsing on the <object> element
  * Add support for HTML 5 <meta charset> and new HEAD elements.
  * Short description of the htextsub example
  * Suppress warning when encode_entities is called with undef
  * HTML::Parser doesn't compile with perl 5.8.0.
* Tue Jan 20 2009 anicka@suse.cz
- update to 3.59
  * Restore perl-5.6 compatibility for HTML::HeadParser.
  * Suppress "Parsing of undecoded UTF-8 will give garbage" warning
    with attr_encoded
  * The <iframe> element content is now parsed in literal mode.
  * Parsing of <script> and <style> content ends on the first end tag
    even when that tag was in a quoted string. That seems to be the
    behaviour of all modern browsers.
  * Implement backquote() attribute
  * Test and documentation tweaks
* Mon Jan 15 2007 anicka@suse.cz
- update to 3.56
  * Cloning of parser state for compatiblity with threads.
  * Don't require whitespace between declaration tokens.
* Tue Jul 11 2006 anicka@suse.cz
- update to 3.55
- minor release
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan  6 2006 anicka@suse.cz
- update to 3.48
* Thu Feb 17 2005 mjancar@suse.cz
- update to 3.45
* Fri Aug  6 2004 mjancar@suse.cz
- update to 3.36
* Thu Feb 26 2004 mjancar@suse.cz
- update to 3.35
* Tue Oct 21 2003 mjancar@suse.cz
- update to 3.33
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Thu Jul 17 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Mon Jun 16 2003 mjancar@suse.cz
- fix filelist
* Fri Jun  6 2003 mjancar@suse.cz
- update to 3.28
- use $RPM_OPT_FLAGS
- don't package MANIFEST
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Wed Jul 10 2002 prehak@suse.cz
- updated to version 3.26
- added eg directory into documentation
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Tue Oct 30 2001 rvasice@suse.cz
- added perl-HTML-Tagset to Requires
* Tue Aug 14 2001 rvasice@suse.cz
- update to version 3.25
* Mon Mar 26 2001 cihlar@suse.cz
- added perl-HTML-Tagset to neededforbuild
- added make test
* Wed Mar 14 2001 cihlar@suse.cz
- update to version 3.19
* Tue Nov 14 2000 cihlar@suse.cz
- renamed perl_htp -> perl-HTML-Parser
- update to version 3.13
* Tue Aug 22 2000 cihlar@suse.cz
- update to version 3.10
- bzipped sources
* Mon Aug 21 2000 ro@suse.de
- adapted for perl-5.6
* Thu Apr 13 2000 ug@suse.de
- added to distribution
